/**
 * Copyright (C) 2007-2011 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGS_H
#define SETTINGS_H

#include <glib.h>

typedef struct _WkSettings
{
    guint     mode;
    gboolean  can_end_session;
    gboolean  fullscreen;
    gboolean  with_clear;
    gboolean  with_timer;
    guint     default_timer;
    gboolean  can_access_fs;
    gint      max_history;
    gint      max_windows;
    gchar    *default_url;
    guint     after_web_session;

    gchar *list_file;
    guint  list_mode;
    GList *list;

    gchar *cookies_file;

    gboolean start_with_session;
    gchar   *playlist_file;
    gboolean hide_toolbar;
    guint    stop_session_after_seconds;
    gchar   *post_session_uri;
    guint    post_session_uri_time;
    gint     start_with_time;

    gchar *user_agent;

    gboolean prestart;
    gchar   *prestart_file;

    gchar *hook_dir;

    const gchar *slideshow_file;
    gboolean     slideshow_hide_pointer;
    gboolean     slideshow_mute;
    gboolean     slideshow_stop_on_event;
    guint        slideshow_refresh_after_minutes;
    guint        slideshow_default_time;

    GHashTable *mime_associations;

    gchar *admin_passwd;

    gchar *tmpdir_name;
} WkSettings;

enum
{
    MODE_KIOSK,
    MODE_DISPLAY
};

enum
{
    LIST_MODE_NONE = 0,
    LIST_MODE_WHITELIST,
    LIST_MODE_BLACKLIST
};

enum
{
    AFTER_WEB_SESSION_HOMEPAGE = 0,
    AFTER_WEB_SESSION_SLIDESHOW,
    AFTER_WEB_SESSION_SESSION
};

/* default settings */
#define PREF_DEFAULT_URL "http://linutop.com"
#define PREF_CAN_END_SESSION FALSE
#define PREF_FULLSCREEN TRUE
#define PREF_MAX_HISTORY 50
#define PREF_MAX_WINDOWS 0
#define PREF_DEFAULT_TIMER 900
#define PREF_WITH_TIMER FALSE
#define PREF_WITH_CLEAR TRUE
#define PREF_CAN_QUIT FALSE
#define PREF_CAN_ACCESS_FS FALSE
#define PREF_LIST_MODE LIST_MODE_NONE
#define PREF_LIST_USE_REGEX FALSE
#define PREF_START_WITH_SESSION TRUE
#define PREF_HIDE_TOOLBAR FALSE
#define PREF_PRESTART FALSE
#define PREF_START_WITH_TIME 300
#define PREF_STOP_SESSION_AFTER_SECONDS 120
#define PREF_POST_SESSION_URI_TIME 10
#define PREF_SLIDESHOW_HIDE_POINTER TRUE
#define PREF_SLIDESHOW_STOP_ON_EVENT TRUE
#define PREF_SLIDESHOW_MUTE TRUE
#define PREF_SLIDESHOW_REFRESH 30
#define PREF_SLIDESHOW_DEFAULT_TIME 5
#define PREF_DEFAULT_AFTER_WEB_SESSION AFTER_WEB_SESSION_SESSION

void wk_settings_load_from_data (WkSettings **settings,
                                 const gchar *data);
void wk_settings_load_from_uri  (WkSettings **settings,
                                 const gchar *uri);

void wk_settings_set_slideshow_from_contents (WkSettings  *settings,
                                              const gchar *contents);

void wk_settings_free_slideshow (WkSettings *settings);
void wk_settings_free           (WkSettings *settings);

GList *wk_settings_expand_playlist (WkSettings *settings);

#endif /* !SETTINGS_H */
