/**
 * Copyright (C) 2007-2011 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif

#ifdef HAVE_SIGNAL_H
#include <signal.h>
#endif

#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <glib.h>
#include <glib/gprintf.h>

#include <gtk/gtk.h>

#include "main.h"
#include "utils.h"
#include "wk-daemon.h"
#include "wk-browser.h"
#include "wk-dbus-service.h"

static gboolean version = FALSE;
static gchar *confdir = NULL;

static GOptionEntry entries[] = {
    { "version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
        &version, "Version information", NULL },
    { "confdir", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
        &confdir, "Use PATH as configuration directory", "PATH" },
    { NULL }
};

static void
on_signal (int signal)
{
    switch (signal)
    {
        case SIGINT:
        case SIGQUIT:
        case SIGTERM:
            stop_unclutter ();
            gtk_main_quit ();
            break;
    }
}

int
main (gint argc, gchar **argv)
{
    struct sigaction action;
    WkDaemon *d;
#if 0
    WkDBusService *dbus_service;
#endif

    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
    textdomain(GETTEXT_PACKAGE);

    action.sa_handler = on_signal;
    sigemptyset (& (action.sa_mask));
    action.sa_flags = 0;
    sigaction (SIGINT, &action, NULL);
    sigaction (SIGQUIT, &action, NULL);
    sigaction (SIGTERM, &action, NULL);

    if (!g_thread_supported ())
        g_thread_init (NULL);
    gdk_threads_init ();

    gtk_init_with_args (&argc, &argv, "", entries, NULL, NULL);

    if (version)
    {
        g_print("%s\n", PACKAGE_STRING);
        return 0;
    }

    if (confdir)
    {
        if (setuid (0) != 0)
        {
            g_fprintf (stderr, _("Only root can use this option.\n"));
            return 1;
        }

        g_fprintf (stderr, "Running with confdir %s\n", confdir);
    }

    gtk_window_set_default_icon_from_file (WEBKIOSKICON, NULL);

#if 0
    dbus_service = g_object_new (WK_TYPE_DBUS_SERVICE, NULL);
#endif

    wk_browser_get (confdir);
    d = wk_daemon_get ();
    wk_daemon_start (d);

    gdk_error_trap_push ();
    gtk_main ();

#if 0
    g_object_unref (G_OBJECT (dbus_service));
#endif

    return 0;
}
